@@ -327,7 +327,7 @@ class URL:
         """
         The URL query string, as raw bytes, excluding the leading b"?".
 
-        This is neccessarily a bytewise interface, because we cannot
+        This is necessarily a bytewise interface, because we cannot
         perform URL decoding of this representation until we've parsed
         the keys and values into a QueryParams instance.
 
@@ -465,7 +465,7 @@ class URL:
             port = kwargs.pop("port", self.port)
 
             if host and ":" in host and host[0] != "[":
-                # IPv6 addresses need to be escaped within sqaure brackets.
+                # IPv6 addresses need to be escaped within square brackets.
                 host = f"[{host}]"
 
             kwargs["netloc"] = (
@@ -534,7 +534,11 @@ class URL:
         #  \_/   \______________/\_________/ \_________/ \__/
         #   |           |            |            |        |
         # scheme     authority       path        query   fragment
-        return URL(self._uri_reference.copy_with(**kwargs).unsplit())
+        new_url = URL(self)
+        new_url._uri_reference = self._uri_reference.copy_with(**kwargs)
+        if new_url.is_absolute_url:
+            new_url._uri_reference = new_url._uri_reference.normalize()
+        return URL(new_url)
 
     def copy_set_param(self, key: str, value: typing.Any = None) -> "URL":
         return self.copy_with(params=self.params.set(key, value))
@@ -907,7 +911,7 @@ class Headers(typing.MutableMapping[str, str]):
     def items(self) -> typing.ItemsView[str, str]:
         """
         Return `(key, value)` items of headers. Concatenate headers
-        into a single comma seperated value when a key occurs multiple times.
+        into a single comma separated value when a key occurs multiple times.
         """
         values_dict: typing.Dict[str, str] = {}
         for _, key, value in self._list:
@@ -922,8 +926,8 @@ class Headers(typing.MutableMapping[str, str]):
     def multi_items(self) -> typing.List[typing.Tuple[str, str]]:
         """
         Return a list of `(key, value)` pairs of headers. Allow multiple
-        occurences of the same key without concatenating into a single
-        comma seperated value.
+        occurrences of the same key without concatenating into a single
+        comma separated value.
         """
         return [
             (key.decode(self.encoding), value.decode(self.encoding))
@@ -932,7 +936,7 @@ class Headers(typing.MutableMapping[str, str]):
 
     def get(self, key: str, default: typing.Any = None) -> typing.Any:
         """
-        Return a header value. If multiple occurences of the header occur
+        Return a header value. If multiple occurrences of the header occur
         then concatenate them together with commas.
         """
         try:
@@ -943,7 +947,7 @@ class Headers(typing.MutableMapping[str, str]):
     def get_list(self, key: str, split_commas: bool = False) -> typing.List[str]:
         """
         Return a list of all header values for a given key.
-        If `split_commas=True` is passed, then any comma seperated header
+        If `split_commas=True` is passed, then any comma separated header
         values are split into multiple return strings.
         """
         get_header_key = key.lower().encode(self.encoding)
@@ -964,8 +968,10 @@ class Headers(typing.MutableMapping[str, str]):
 
     def update(self, headers: HeaderTypes = None) -> None:  # type: ignore
         headers = Headers(headers)
-        for key, value in headers.raw:
-            self[key.decode(headers.encoding)] = value.decode(headers.encoding)
+        for key in headers.keys():
+            if key in self:
+                self.pop(key)
+        self._list.extend(headers._list)
 
     def copy(self) -> "Headers":
         return Headers(self, encoding=self.encoding)
@@ -1365,7 +1371,7 @@ class Response:
     @property
     def apparent_encoding(self) -> typing.Optional[str]:
         """
-        Return the encoding, as detemined by `charset_normalizer`.
+        Return the encoding, as determined by `charset_normalizer`.
         """
         content = getattr(self, "_content", b"")
         if len(content) < 32:
